==> dotup_dart_geolocation_here_maps-0.1.0.tar.gz: lib/src/ApiResults/HereLocation.dart <==

import 'package:dotup_dart_geolocation_core/dotup_dart_geolocation_core.dart';

import 'HereMapView.dart';

class HereLocation {
  String? locationId;
  String? locationType;
  GeoCoordinates? displayPosition;
  List<GeoCoordinates>? navigationPosition;
  HereMapView? mapView;
  Address? address;

  HereLocation(
      {this.locationId, this.locationType, this.displayPosition, this.navigationPosition, this.mapView, this.address});

  HereLocation.fromJson(Map<String, dynamic> json) {
    locationId = json['LocationId'];
    locationType = json['LocationType'];
    displayPosition = json['DisplayPosition'] != null ? GeoCoordinates.fromMap(json['DisplayPosition']) : null;
    if (json['NavigationPosition'] != null) {
      navigationPosition = [];
      json['NavigationPosition'].forEach((v) {
        navigationPosition!.add(GeoCoordinates.fromMap(v));
      });
    }
    mapView = json['MapView'] != null ? HereMapView.fromJson(json['MapView']) : null;
    address = json['Address'] != null ? Address.fromMap(json['Address']) : null;
  }

  Map<String, dynamic> toJson() {
    final data = <String, dynamic>{};
    data['LocationId'] = locationId;
    data['LocationType'] = locationType;
    if (displayPosition != null) {
      data['DisplayPosition'] = displayPosition!.toJson();
    }
    if (navigationPosition != null) {
      data['NavigationPosition'] = navigationPosition!.map((v) => v.toJson()).toList();
    }
    if (mapView != null) {
      data['MapView'] = mapView!.toJson();
    }
    if (address != null) {
      data['Address'] = address!.toJson();
    }
    return data;
  }
}

==> dotup_dart_geolocation_here_maps-0.1.1.tar.gz: lib/src/ApiResults/HereLocation.dart <==
import 'package:dotup_dart_geolocation_core/dotup_dart_geolocation_core.dart';

import 'HereAddress.dart';
import 'HereMapView.dart';

class HereLocation {
  late final String? locationId;
  late final String? locationType;
  late final GeoCoordinates? displayPosition;
  late final List<GeoCoordinates>? navigationPosition;
  late final HereMapView? mapView;
  late final HereAddress? address;

  HereLocation(
      {this.locationId, this.locationType, this.displayPosition, this.navigationPosition, this.mapView, this.address});

  HereLocation.fromJson(Map<String, dynamic> json) {
    locationId = json['LocationId'];
    locationType = json['LocationType'];
    displayPosition = json['DisplayPosition'] != null ? GeoCoordinates.fromMap(json['DisplayPosition']) : null;
    if (json['NavigationPosition'] != null) {
      navigationPosition = [];
      json['NavigationPosition'].forEach((v) {
        navigationPosition!.add(GeoCoordinates.fromMap(v));
      });
    }
    mapView = json['MapView'] != null ? HereMapView.fromJson(json['MapView']) : null;
    address = json['Address'] != null ? HereAddress.fromMap(json['Address']) : null;
  }

  Map<String, dynamic> toJson() {
    final data = <String, dynamic>{};
    data['LocationId'] = locationId;
    data['LocationType'] = locationType;
    if (displayPosition != null) {
      data['DisplayPosition'] = displayPosition!.toJson();
    }
    if (navigationPosition != null) {
      data['NavigationPosition'] = navigationPosition!.map((v) => v.toJson()).toList();
    }
    if (mapView != null) {
      data['MapView'] = mapView!.toJson();
    }
    if (address != null) {
      data['Address'] = address!.toJson();
    }
    return data;
  }
}
